@@ -16,7 +16,7 @@
 
 nearestPump <- function(pump.select = NULL, metric = "walking", vestry = FALSE,
   weighted = TRUE, case.set = "observed", distance.unit = "meter",
-  time.unit = "second", walking.speed = 5, multi.core = FALSE,
+  time.unit = "second", walking.speed = 5, multi.core = TRUE,
   dev.mode = FALSE) {
 
   if (vestry) p.id <- cholera::pumps.vestry$id else p.id <- cholera::pumps$id
