@@ -23,16 +23,15 @@ segmentLocator <- function(id = "216-1", zoom = 0.5, cases = "address",
   distance.unit = "meter", time.unit = "second", walking.speed = 5,
   add.title = TRUE, add.subtitle = TRUE, highlight = TRUE) {
 
-  if (is.character(id) == FALSE) {
-    stop('id\'s type must be a character.')
-  }
+  if (is.character(id) == FALSE) stop('id\'s type must be a character.',
+    call. = FALSE)
 
   if (id %in% cholera::road.segments$id == FALSE) {
-    stop("Invalid segment ID. See cholera::road.segments.")
+    stop("Invalid segment ID. See cholera::road.segments.", call. = FALSE)
   }
 
   if (distance.unit %in% c("meter", "yard", "native") == FALSE) {
-    stop('distance.unit must be "meter", "yard" or "native".')
+    stop('distance.unit must be "meter", "yard" or "native".', call. = FALSE)
   }
 
   st <- cholera::road.segments[cholera::road.segments$id == id, ]
@@ -54,8 +53,8 @@ segmentLocator <- function(id = "216-1", zoom = 0.5, cases = "address",
                  max(st[, c("x1", "x2")]) + zoom)
       y.rng <- c(min(st[, c("y1", "y2")]) - zoom,
                  max(st[, c("y1", "y2")]) + zoom)
-    } else stop("If numeric, zoom must be >= 0.")
-  } else stop("zoom must either be logical or numeric.")
+    } else stop("If numeric, zoom must be >= 0.", call. = FALSE)
+  } else stop("zoom must either be logical or numeric.", call. = FALSE)
 
   roads.list <- split(cholera::roads[, c("x", "y")], cholera::roads$street)
 
