@@ -19,22 +19,24 @@
 #' }
 #' @export
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' neighborhoodWalking()
 #' neighborhoodWalking(pump.select = -6)
 #' }
 
 neighborhoodWalking <- function(pump.select = NULL, vestry = FALSE,
-  weighted = TRUE, case.set = "observed", multi.core = FALSE,
+  weighted = TRUE, case.set = "observed", multi.core = TRUE,
   dev.mode = FALSE) {
 
   if (is.null(pump.select) == FALSE) {
-    if (is.numeric(pump.select) == FALSE) stop("pump.select must be numeric.")
+    if (is.numeric(pump.select) == FALSE) {
+      stop("pump.select must be numeric.", call. = FALSE)
+    }
     if (length(pump.select) == 1) {
       if (pump.select == 2) {
         msg1 <- "You can't just select the pump on Adam and Eve Court (#2).\n"
         msg2 <- " It's an isolate, unreachable for observed fatalities."
-        stop(msg1, msg2)
+        stop(msg1, msg2, call. = FALSE)
       }
     }
 
@@ -47,12 +49,13 @@ neighborhoodWalking <- function(pump.select = NULL, vestry = FALSE,
     p.ID <- seq_len(p.count)
 
     if (any(abs(pump.select) %in% p.ID == FALSE)) {
-      stop('With vestry = ', vestry, ', 1 >= |pump.select| <= ', p.count)
+      stop('With vestry = ', vestry, ', 1 >= |pump.select| <= ', p.count,
+        call. = FALSE)
     }
   }
 
   if (case.set %in% c("observed", "expected", "snow") == FALSE) {
-    stop('case.set must be "observed", "expected" or "snow".')
+    stop('case.set must be "observed", "expected" or "snow".', call. = FALSE)
   }
 
   snow.colors <- snowColors(vestry = vestry)
@@ -119,7 +122,7 @@ neighborhoodWalking <- function(pump.select = NULL, vestry = FALSE,
 #' @note When plotting area graphs with simulated data (i.e., \code{case.set = "expected"}), there may be discrepancies between observed cases and expected neighborhoods, particularly between neighborhoods.
 #' @export
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' plot(neighborhoodWalking())
 #' plot(neighborhoodWalking(case.set = "expected"))
 #' plot(neighborhoodWalking(case.set = "expected"), type = "area.points")
@@ -313,7 +316,7 @@ plot.walking <- function(x, type = "road", msg = FALSE, ...) {
 #' @return A list of argument values.
 #' @export
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' neighborhoodWalking()
 #' print(neighborhoodWalking())
 #' }
@@ -330,7 +333,7 @@ print.walking <- function(x, ...) {
 #' @return An R vector.
 #' @export
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' summary(neighborhoodWalking())
 #' }
 
@@ -339,7 +342,6 @@ summary.walking <- function(object, ...) {
     out <- vapply(object$paths, length, numeric(1L))
     out <- stats::setNames(out, paste0("p", object$pumpID))
   } else if (object$case.set == "expected") {
-
     out <- expectedCount(object)
   }
   out
